@@ -1,6 +1,7 @@
 import os
 from pathlib import Path
 from time import perf_counter
+from typing import Iterable
 
 from natsort import natsorted
 from nbclient import NotebookClient
@@ -9,11 +10,14 @@ from nbformat import read as read_nb
 from nbformat import write as write_nb
 
 
-def _list_nbs_in_md(nb_folder, md_filename="index.md"):
+def _list_nbs_in_md(nb_folder: Path, md_filename="index.md"):
     notebooks = []
     names = []
 
     index_path = nb_folder / md_filename
+    if not index_path.exists():
+        # see whether there is a file one level down
+        index_path = Path(nb_folder.as_posix() + ".md")
     if index_path.exists():
         print(f"Reading {index_path}", flush=True)
         with open(index_path) as f:
@@ -78,22 +82,25 @@ def _print_cell_output(cell, cell_index, execute_reply):
 
 def execute_notebooks(
     nb_file_folder: Path,
+    skip_nbs: Iterable = None,
     write: bool = True,
     print_cells: bool = False,
     print_outputs: bool = False,
 ):
     """Execute all notebooks in the folder.
 
-    If `write` is `True`, will also add consecutive execution count numbers to
-    make integrity check pass.
+    If `write` is `True`, will also add consecutive execution count numbers
+    to make integrity check pass.
 
     Ignores .ipynb_checkpoints.
 
     Args:
         nb_file_folder: Path to folder with notebooks or a notebook to execute.
+        skip_nbs: Skip the execution of these notebooks.
+            Use the stem of the filename to indicate a notebook in the folder.
         write: If `True`, writes the execution results to the notebooks.
         print_cells: If `True`, prints cell indices and content
-        on the start of the execution.
+                     on the start of the execution.
         print_outputs: If `True`, prints cell output for executed cells.
     """
     print(f"Executing notebooks in {nb_file_folder}", flush=True)
@@ -117,16 +124,19 @@ def execute_notebooks(
         # notebooks are part of documentation and indexed
         # by a sphinx myst index.md file
         # the order of execution matters!
-        notebooks, names = _list_nbs_in_md(nb_folder, md_filename="index.md")
-        for name in names:
-            md_filename = nb_folder / f"{name}.md"
-            if md_filename.exists():
-                try:
-                    notebooks_, _ = _list_nbs_in_md(nb_folder, md_filename=f"{name}.md")
-                    notebooks += notebooks_
-                except UnicodeDecodeError:
-                    print(f"Ignoring {name}.md due to special characters", flush=True)
-                    continue
+        notebooks, _ = _list_nbs_in_md(nb_folder, md_filename="index.md")
+
+        # nesting is problematic as notebooks might be in other folders but
+        # linked in these markdowns
+        # for name in names:
+        #     md_filename = nb_folder / f"{name}.md"
+        #     if md_filename.exists():
+        #         try:
+        #             notebooks_, _ = _list_nbs_in_md(nb_folder, md_filename=f"{name}.md")  # noqa
+        #             notebooks += notebooks_
+        #         except UnicodeDecodeError:
+        #             print(f"Ignoring {name}.md due to special characters", flush=True)
+        #             continue
 
         notebooks_unindexed = []
         for nb in nb_folder.glob("./*.ipynb"):
@@ -139,10 +149,15 @@ def execute_notebooks(
 
     print(f"Scheduled: {[nb.stem for nb in notebooks]}", flush=True)
 
+    cwd = os.getcwd()
     os.chdir(nb_folder)
 
+    if not skip_nbs:
+        skip_nbs = set()
+
     for nb in notebooks:
-        if ".ipynb_checkpoints/" in str(nb):
+        if ".ipynb_checkpoints/" in str(nb) or nb.stem in skip_nbs:
+            print("skipped", nb)
             continue
 
         t_start = perf_counter()
@@ -178,3 +193,4 @@ def execute_notebooks(
         f"Total time: {total_time_elapsed:.3f}s",
         flush=True,
     )
+    os.chdir(cwd)
