@@ -15,3 +15,9 @@ def test_execute_file():
 
 def test_execute_file_reply():
     execute_notebooks(nb_folder / "test.ipynb", write=False, print_outputs=True)
+
+
+def test_execute_skipped():
+    execute_notebooks(
+        nb_folder, skip_nbs={"skip.ipynb"}, write=False, print_outputs=True
+    )
